do_fortran_indexing = 1;
a = [1,2;3,4];
a_fvec = [1;3;2;4];
a_col_1 = [1;3];
a_col_2 = [2;4];
a_row_1 = [1,2];
a_row_2 = [3,4];
a(2)
